referrerpolicy=no-referrer-when-downgrade

QueueTotals

Type Alias QueueTotals 

pub type QueueTotals<T: Config> = StorageValue<_GeneratedPrefixForStorageQueueTotals<T>, BoundedVec<(u32, <<T as Config>::Currency as FunInspect<<T as Config>::AccountId>>::Balance), <T as Config>::QueueCount>, ValueQuery, OnEmptyQueueTotals<T>>;
The totals of items and balances within each queue. Saves a lot of storage reads in the case of sparsely packed queues.

The vector is indexed by duration in Periods, offset by one, so information on the queue whose duration is one Period would be storage 0.

Storage type is [StorageValue] with value type QueueTotalsTypeOf < T >.

Aliased Type

pub struct QueueTotals<T: Config>(/* private fields */);